# MLSpace: Hassle free machine learning & deep learning development

- No need to worry about CUDA
- No need to worry about cuDNN
- No need to worry about TensorFlow version
- No need to worry about PyTorch version
- No need to install any libraries


*coming soon*

**NOTE: PRs are currently not accepted. All PRs will be closed. Please use issues instead.**